##  Introduction
SAP LeanIX allows a collaborative approach to collect and maintain data. Stakeholders who know the required data best - such as application owners, business owners, data architects, etc. - play an important role in contributing and maintaining accurate information.
Users with appropriate permissions, by default, members and administrators, can edit and add data in fact sheets. Admins can configure these permissions to include other user roles, including custom roles. They can also modify the permissions for each fact sheet type to restrict or expand write access. To learn more, see [Fact Sheet Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Configure fact sheet permissions for non-admin user roles.").
